@@ -7,11 +7,12 @@
   
  */
 
-#include <string.h>
+#include "afm.hh"
+
+#include <cstring>
 
 #include "warn.hh"
 #include "libc-extension.hh"
-#include "afm.hh"
 #include "dimensions.hh"
 
 Adobe_font_metric::Adobe_font_metric (AFM_Font_info *fi)
