@@ -8,8 +8,6 @@
 
 #include "engraver.hh"
 #include "group-interface.hh"
-#include "item.hh"
-#include "event.hh"
 #include "arpeggio.hh"
 #include "stem.hh"
 #include "rhythmic-head.hh"
