@@ -7,18 +7,15 @@
   
  */
 
+#include "engraver.hh"
 #include "beaming.hh"
-#include "event.hh"
 #include "beam.hh"
 #include "stem.hh"
 #include "warn.hh"
-#include "engraver-group-engraver.hh"
 #include "bar-line.hh"
 #include "rest.hh"
-#include "engraver.hh"
 #include "item.hh"
 #include "spanner.hh"
-#include "duration.hh"
 #include "context.hh"
 
 class Auto_beam_engraver : public Engraver
@@ -282,7 +279,7 @@ Auto_beam_engraver::create_beam ()
   if (to_boolean (get_property ("skipTypesetting")))
     return 0;
   
-  Spanner *beam = new Spanner (beam_settings_);
+  Spanner *beam = new Spanner (beam_settings_, context ()->get_grob_key ("Beam"));
   for (int i = 0; i < stems_->size (); i++)
     {
       /*
