@@ -7,17 +7,14 @@
 */
 
 
-#include <limits.h>		// INT_MAX
-#include <assert.h>
-
-#include "flower-proto.hh"
-#include "string.hh"
-#include "source-file.hh"
 #include "binary-source-file.hh"
+
+#include <climits>		// INT_MAX
+
 #include "string-convert.hh"
 
-Binary_source_file::Binary_source_file (String& filename_string)
-  : Source_file (filename_string)
+Binary_source_file::Binary_source_file (String& file_name_string)
+  : Source_file (file_name_string)
 {
 }
 
