@@ -9,7 +9,6 @@
 #include "engraver.hh"
 #include "protected-scm.hh"
 #include "break-align-interface.hh"
-#include "item.hh"
 #include "align-interface.hh"
 #include "axis-group-interface.hh"
 #include "context.hh"
@@ -92,13 +91,11 @@ Break_align_engraver::acknowledge_grob (Grob_info inf)
 	{
 	  align_ = make_item ("BreakAlignment", SCM_EOL);
 
-	  
-
 	  Context*origin = inf.origin_contexts (this)[0];
-	  left_edge_ =  make_item_from_properties (origin->implementation (),
-						   ly_symbol2scm ("LeftEdge"),
-						   SCM_EOL
-						   );
+	  left_edge_ = make_item_from_properties (dynamic_cast<Engraver*> (origin->implementation ()),
+						  ly_symbol2scm ("LeftEdge"),
+						  SCM_EOL,
+						  "LeftEdge");
 	  add_to_group (left_edge_->get_property ("break-align-symbol"),
 			left_edge_);
 	}
