@@ -8,7 +8,6 @@
 */
 
 #include "context.hh"
-#include "grob-selector.hh"
 #include "engraver.hh"
 #include "item.hh"
 #include "main.hh"
@@ -196,27 +195,28 @@ updated_grob_properties (Context * tg, SCM sym)
 }
 
 Item *
-make_item_from_properties (Translator *tr, SCM x, SCM cause)
+make_item_from_properties (Engraver *tr, SCM x, SCM cause, const char * name)
 {
   Context *context = tr->context ();
   
   SCM props = updated_grob_properties (context, x);
-  Item *it = new Item (props);
-#ifdef TWEAK 
-  Grob_selector::register_grob (context, it);
-#endif
+
+  Object_key const*key = context->get_grob_key (name);
+  Item *it = new Item (props, key);
+  scm_gc_unprotect_object (key->self_scm ());
+
   dynamic_cast<Engraver*>(tr)->announce_grob (it, cause);
 
   return it;
 }
 
 Spanner*
-make_spanner_from_properties (Translator *tr, SCM x, SCM cause)
+make_spanner_from_properties (Engraver *tr, SCM x, SCM cause, const char *name)
 {
-  Context *tg = tr->context ();
+  Context *context = tr->context ();
 
-  SCM props = updated_grob_properties (tg, x);
-  Spanner *it = new Spanner (props);
+  SCM props = updated_grob_properties (context, x);
+  Spanner *it = new Spanner (props, context->get_grob_key (name));
 
   dynamic_cast<Engraver*>(tr)->announce_grob (it, cause);
 
