@@ -7,9 +7,9 @@
 
 */
 
-#include "context-def.hh"
-#include "context-selector.hh"
 #include "context.hh"
+
+#include "context-def.hh"
 #include "ly-smobs.icc"
 #include "main.hh"
 #include "output-def.hh"
@@ -17,6 +17,7 @@
 #include "score-context.hh"
 #include "translator-group.hh"
 #include "warn.hh"
+#include "lilypond-key.hh"
 
 bool
 Context::is_removable () const
@@ -63,9 +64,7 @@ Context::add_context (Context *t)
   if (!t->init_)
     {
       t->init_ = true;
-#ifdef TWEAK 
-      Context_selector::register_context (t);
-#endif  
+
       scm_gc_unprotect_object (ts);
       Context_def *td = unsmob_context_def (t->definition_);
 
@@ -79,8 +78,15 @@ Context::add_context (Context *t)
     }
 }
 
-Context::Context ()
+Object_key const*
+Context::get_key () const
 {
+  return key_;
+}
+
+Context::Context (Object_key const* key)
+{
+  key_ = key;
   daddy_context_ = 0;
   init_ = false;
   aliases_ = SCM_EOL;
@@ -134,18 +140,16 @@ Context::find_create_context (SCM n, String id, SCM operations)
 	{
 	  SCM ops = (i == path.size () -1) ? operations : SCM_EOL;
 
-	  Context * new_group
-	    = path[i]->instantiate (ops);
-
+	  String this_id = "";
 	  if (i == path.size () -1)
 	    {
-	      new_group->id_string_ = id;
+	      this_id = id;
 	    }
 
-	  current->add_context (new_group);
-	  apply_property_operations (new_group, ops);
-	  
-	  current = new_group;
+
+	  current = current->create_context (path[i],
+					     this_id,
+					     ops); 
 	}
 
       return current;
@@ -167,6 +171,65 @@ Context::find_create_context (SCM n, String id, SCM operations)
   return ret;
 }
 
+
+Context*
+Context::create_context (Context_def * cdef,
+			 String id,
+			 SCM ops)
+{
+  String type = ly_symbol2string (cdef->get_context_name());
+  Object_key const *key = get_context_key (type, id);
+  Context * new_group
+    = cdef->instantiate (ops, key);
+  scm_gc_unprotect_object (key->self_scm ());
+	  
+  new_group->id_string_ = id;
+  add_context (new_group);
+  apply_property_operations (new_group, ops);
+
+  return new_group;
+}
+
+Object_key const*
+Context::get_context_key (String type, String id)
+{
+  String now_key = type + "@" + id;
+
+  int disambiguation_count = 0;
+  if (context_counts_.find (now_key) != context_counts_.end ())
+    {
+      disambiguation_count = context_counts_[now_key];
+    }
+
+  context_counts_[now_key] = disambiguation_count + 1;
+  
+  
+  return new Lilypond_context_key (get_key (),
+				   now_mom(),
+				   type, id,
+				   disambiguation_count);
+}
+
+Object_key const*
+Context::get_grob_key (String name) 
+{
+  int disambiguation_count = 0;
+  if (grob_counts_.find (name) != grob_counts_.end ())
+    {
+      disambiguation_count = grob_counts_[name];
+    }
+  grob_counts_[name] = disambiguation_count + 1;
+
+  Object_key * k = new Lilypond_grob_key (get_key(),
+					  now_mom(),
+					  name,
+					  disambiguation_count);
+
+  return k;					  
+}
+
+
+
 /*
   Default child context as a SCM string, or something else if there is
   none.
@@ -194,14 +257,15 @@ Context::get_default_interpreter ()
       SCM nm = default_child_context_name ();
       SCM st = find_context_def (get_output_def (), nm);
 
+      String name = ly_symbol2string (nm);
       Context_def *t = unsmob_context_def (st);
       if (!t)
 	{
-	  warning (_f ("can't find or create: `%s'", ly_symbol2string (nm).to_str0 ()));
+	  warning (_f ("can't find or create: `%s'", name.to_str0 ()));
 	  t = unsmob_context_def (this->definition_);
 	}
-      Context *tg = t->instantiate (SCM_EOL);
-      add_context (tg);
+
+      Context *tg = create_context (t, "", SCM_EOL);
       if (!tg->is_bottom_context ())
 	return tg->get_default_interpreter ();
       else
@@ -397,7 +461,7 @@ SCM
 Context::mark_smob (SCM sm)
 {
   Context *me = (Context*) SCM_CELL_WORD_1 (sm);
-  
+  scm_gc_mark (me->key_->self_scm ());  
   scm_gc_mark (me->context_list_);
   scm_gc_mark (me->aliases_);
   scm_gc_mark (me->definition_);  
@@ -451,3 +515,14 @@ Context::implementation () const
 {
   return dynamic_cast<Translator_group*> (unsmob_translator (implementation_));
 }
+
+void
+Context::clear_key_disambiguations ()
+{
+  grob_counts_.clear();
+  context_counts_.clear();
+  for (SCM s = context_list_; scm_is_pair (s); s = scm_cdr (s))
+    {
+      unsmob_context (scm_car (s))->clear_key_disambiguations();
+    }
+}
