@@ -11,11 +11,8 @@
 #include "dimensions.hh"
 #include "directional-element-interface.hh"
 #include "engraver.hh"
-#include "event.hh"
-#include "group-interface.hh"
 #include "hairpin.hh"
 #include "interval.hh"
-#include "item.hh"
 #include "note-column.hh"
 #include "paper-column.hh"
 #include "script-interface.hh"
