@@ -6,16 +6,16 @@
   (c) 1997--2004 Han-Wen Nienhuys <hanwen@cs.uu.nl>
 */
 
-#include "music.hh"
 #include "engraver.hh"
-#include "engraver-group-engraver.hh"
-#include "grob.hh"
+
+#include "music.hh"
 #include "score-engraver.hh"
 #include "warn.hh"
 #include "spanner.hh"
 #include "item.hh"
 #include "context.hh"
 #include "score-context.hh"
+#include "lilypond-key.hh"
 
 Engraver_group_engraver*
 Engraver::get_daddy_engraver () const
