@@ -5,21 +5,27 @@
 
   (c) 1997--2004 Han-Wen Nienhuys <hanwen@cs.uu.nl>
 */
-#include <stdio.h>
+
+#include "global-context.hh"
+
+#include <cstdio>
 
 #include "warn.hh"
-#include "music.hh"
 #include "event.hh"
 #include "music-list.hh"
 #include "music-iterator.hh"
-#include "global-context.hh"
 #include "score-context.hh"
 #include "context-def.hh"
 #include "output-def.hh"
-#include "grace-fixup.hh"
+#include "lilypond-key.hh"
 
-Global_context::Global_context (Output_def *o, Moment final)
+Global_context::Global_context (Output_def *o, Moment final, Object_key *key)
+  : Context (new Lilypond_context_key(key,
+				      Moment(0),
+				      "Global", "", 0))
 {
+  scm_gc_unprotect_object (key_->self_scm());
+  
   output_def_ = o;
   final_mom_ = final;
   definition_ = find_context_def (o, ly_symbol2scm ("Global"));
@@ -75,8 +81,10 @@ Global_context::prepare (Moment m)
   prev_mom_  = now_mom_;
   now_mom_ = m;
 
+  clear_key_disambiguations ();
   if (get_score_context ())
     get_score_context ()->prepare (m);
+  
 }
 
 Moment
@@ -151,13 +159,15 @@ Global_context::run_iterator_on_me (Music_iterator * iter)
 
       if (!get_score_context ()) 
 	{
-	  SCM key = ly_symbol2scm ("Score");
-	  Context_def * t = unsmob_context_def (find_context_def (get_output_def (), key));
+	  SCM sym = ly_symbol2scm ("Score");
+	  Context_def * t = unsmob_context_def (find_context_def (get_output_def (), sym));
 	  if (!t)
 	    error (_f ("can't find `%s' context", "Score"));
 
-	  Context *c = t->instantiate (SCM_EOL);
+	  Object_key const *key = get_context_key ("Score", "");
+	  Context *c = t->instantiate (SCM_EOL, key);
 	  add_context (c);
+	  scm_gc_unprotect_object (key->self_scm());
 
 	  Score_context *sc = dynamic_cast<Score_context*> (c);
 	  sc->prepare (w);
