@@ -6,9 +6,10 @@
   (c) 1997--2004 Han-Wen Nienhuys <hanwen@cs.uu.nl>
 */
 
+#include "grob.hh"
 
-#include <string.h>
-#include <math.h>
+#include <cstring>
+#include <cmath>
 
 #include "main.hh"
 #include "input-smob.hh"
@@ -17,9 +18,7 @@
 #include "misc.hh"
 #include "paper-score.hh"
 #include "stencil.hh"
-#include "grob.hh"
 #include "warn.hh"
-#include "spanner.hh"
 #include "system.hh"
 #include "item.hh"
 #include "stencil.hh"
@@ -29,6 +28,12 @@
 
 #include "ly-smobs.icc"
 
+Grob * 
+Grob::clone (int count) const
+{
+  return new Grob (*this, count);
+}
+
 /* TODO:
 
   - remove dynamic_cast<Spanner,Item> and put this code into respective
@@ -37,8 +42,10 @@
 #define HASH_SIZE 3
 #define INFINITY_MSG "Infinity or NaN encountered"
 
-Grob::Grob (SCM basicprops)
+Grob::Grob (SCM basicprops,
+	    Object_key const* key)
 {
+  key_ = key;
   /* FIXME: default should be no callback.  */
   self_scm_ = SCM_EOL;
   pscore_= 0;
@@ -102,9 +109,10 @@ Grob::Grob (SCM basicprops)
     }
 }
 
-Grob::Grob (Grob const &s)
+Grob::Grob (Grob const &s, int copy_index)
    : dim_cache_ (s.dim_cache_)
 {
+  key_ = new Copied_key (s.key_, copy_index);
   original_ = (Grob*) &s;
   self_scm_ = SCM_EOL;
 
@@ -117,6 +125,7 @@ Grob::Grob (Grob const &s)
   pscore_ = 0;
 
   smobify_self ();
+  scm_gc_unprotect_object (key_->self_scm ());
 }
 
 Grob::~Grob ()
@@ -234,7 +243,6 @@ Grob::get_uncached_stencil () const
 
 /*
   VIRTUAL STUBS
-
  */
 void
 Grob::do_break_processing ()
@@ -593,7 +601,7 @@ Grob::mark_smob (SCM ses)
 {
   Grob *s = (Grob*) SCM_CELL_WORD_1 (ses);
   scm_gc_mark (s->immutable_property_alist_);
-
+  scm_gc_mark (s->key_->self_scm ());
   for (int a = 0 ; a < 2; a++)
     {
       scm_gc_mark (s->dim_cache_[a].offset_callbacks_);
@@ -638,6 +646,8 @@ Grob::discretionary_processing ()
 {
 }
 
+
+
 bool
 Grob::internal_has_interface (SCM k)
 {
@@ -662,6 +672,12 @@ ly_scm2grobs (SCM lst)
   return arr;
 }
 
+Object_key const *
+Grob::get_key () const
+{
+  return key_;
+}
+
 /** Return SCM list of Grob array A */
 SCM
 ly_grobs2scm (Link_array<Grob> a)
