@@ -6,24 +6,21 @@
   (c) 1997--2004 Han-Wen Nienhuys <hanwen@cs.uu.nl>
 */
 
-#include <ctype.h>
+#include "lily-lexer.hh"
+
+#include <cctype>
 #include <sstream>
 
-#include "lily-proto.hh"
 #include "scm-hash.hh"
 #include "interval.hh"
-#include "lily-guile.hh"
 #include "parser.hh"
 #include "keyword.hh"
-#include "lily-lexer.hh"
 #include "warn.hh"
 #include "source-file.hh"
 #include "main.hh"
-#include "input.hh"
 #include "moment.hh"
 #include "ly-module.hh"
 
-
 static Keyword_ent the_key_tab[] = {
   {"accepts", ACCEPTS},
   {"addquote", ADDQUOTE},
@@ -57,13 +54,13 @@ static Keyword_ent the_key_tab[] = {
   {"midi", MIDI},
   {"name", NAME},
   {"new", NEWCONTEXT},
+  {"objectid", OBJECTID},
   {"notemode", NOTEMODE},
   {"octave", OCTAVE},
   {"once", ONCE},
   {"override", OVERRIDE},
   {"paper", PAPER},
   {"partial", PARTIAL},
-  {"quote", QUOTE},
   {"relative", RELATIVE},
   {"remove", REMOVE},
   {"repeat", REPEAT},
