@@ -7,16 +7,16 @@
        Jan Nieuwenhuizen <janneke@gnu.org>
 */
 
+#include "lily-parser.hh"
+
 #include "book.hh"
-#include "context-selector.hh"
-#include "grob-selector.hh"
+#include "lilypond-key.hh"
 #include "file-name.hh"
 #include "file-path.hh"
 #include "lily-version.hh"
 #include "ly-module.hh"
 #include "main.hh"
 #include "lily-lexer.hh"
-#include "lily-parser.hh"
 #include "output-def.hh"
 #include "paper-book.hh"
 #include "parser.hh"
@@ -24,7 +24,6 @@
 #include "source.hh"
 #include "warn.hh"
 
-
 Lily_parser::Lily_parser (Sources *sources)
 {
   book_count_ = 0;
@@ -102,19 +101,11 @@ Lily_parser::parse_file (String init, String name, String out_name)
   set_yydebug (0);
 
   lexer_->new_input (init, sources_);
-#ifdef TWEAK
+
   File_name f (name);
   String s = global_path.find (f.base_ + ".twy");
-  if (s == "")
-    Grob_selector::set_tweaks (SCM_EOL);
-  else
-    {
-      s = gulp_file_to_string (s, false);
-      SCM tweaks = scm_eval_string (scm_makfrom0str (s.to_str0 ()));
-      Grob_selector::set_tweaks (tweaks);
-    }
-  Context_selector::set_tweaks (SCM_EOL);
-#endif  
+  s = gulp_file_to_string (s, false);
+  scm_eval_string (scm_makfrom0str (s.to_str0 ()));
 
   /* Read .ly IN_FILE, lex, parse, write \score blocks from IN_FILE to
      OUT_FILE (unless IN_FILE redefines output file name).  */
@@ -433,6 +424,8 @@ LY_DEFINE (ly_parser_print_score, "ly:parser-print-score",
   Lily_parser *parser = unsmob_my_lily_parser (parser_smob);
   Score *score = unsmob_score (score_smob);
 
+  Object_key * key = new Lilypond_general_key (0, score->user_key_, 0);
+  
   if (score->error_found_)
     return SCM_UNSPECIFIED;
   
@@ -453,16 +446,19 @@ LY_DEFINE (ly_parser_print_score, "ly:parser-print-score",
   for (int i = 0; i < score->defs_.size (); i++)
     default_rendering (score->get_music (), score->defs_[i]->self_scm (),
 		       paper,
-		       header, os);
+		       header, os,
+		       key->self_scm ());
 
   if (score->defs_.is_empty ())
     {
       Output_def *layout = get_layout (parser);
       default_rendering (score->get_music(), layout->self_scm (),
 			 get_paper (parser)->self_scm (),
-			 header, os);
+			 header, os, key->self_scm ());
       scm_gc_unprotect_object (layout->self_scm ());
     }
+
+  scm_gc_unprotect_object (key->self_scm ());
   return SCM_UNSPECIFIED;
 }
 
@@ -506,8 +502,8 @@ LY_DEFINE (ly_parser_print_book, "ly:parser-print-book",
   (*c)++;
 
   Output_def *layout = get_layout (parser);
-
   Paper_book* pb = book->process (outname.to_string (), layout);
+  
   if (pb)
     {
       pb->output (outname.to_string ());
