@@ -7,8 +7,11 @@
 
   Jan Nieuwenhuizen <janneke@gnu.org>
 */
-#include <math.h>
-#include <ctype.h>
+
+#include "lookup.hh"
+
+#include <cmath>
+#include <cctype>
 
 #include "line-interface.hh"
 #include "warn.hh"
@@ -18,10 +21,7 @@
 #include "file-path.hh"
 #include "main.hh"
 #include "lily-guile.hh"
-#include "stencil.hh"
-#include "lookup.hh"
 #include "font-metric.hh"
-#include "interval.hh"
 
 Stencil
 Lookup::dot (Offset p, Real radius)
@@ -76,13 +76,10 @@ Lookup::beam (Real slope, Real width, Real thick, Real blot)
 }
 
 Stencil
-Lookup::dashed_slur (Bezier b, Real thick, Real dash_period, Real dash_fraction)
+Lookup::dashed_slur (Bezier b, Real thick, Real dash)
 {
   SCM l = SCM_EOL;
 
-  Real on = dash_fraction * dash_period; 
-  Real off = dash_period - on; 
-
   for (int i= 4; i -- ;)
     {
       l = scm_cons (ly_offset2scm (b.control_[i]), l);
@@ -90,8 +87,7 @@ Lookup::dashed_slur (Bezier b, Real thick, Real dash_period, Real dash_fraction)
 
   SCM at = (scm_list_n (ly_symbol2scm ("dashed-slur"),
 			       scm_make_real (thick), 
-			       scm_make_real (on),
-			       scm_make_real (off),
+			       scm_make_real (dash),
 			       ly_quote_scm (l),
 			       SCM_UNDEFINED));
 
@@ -657,7 +653,7 @@ Lookup::repeat_slash (Real w, Real s, Real t)
   SCM sl = scm_make_real (s);
   SCM thick = scm_make_real (t);
   SCM slashnodot = scm_list_n (ly_symbol2scm ("repeat-slash"),
-			    wid, sl, thick, SCM_UNDEFINED);
+			       wid, sl, thick, SCM_UNDEFINED);
 
   Box b (Interval (0, w + sqrt (sqr (t/s) + sqr (t))),
 	 Interval (0, w * s));
@@ -674,14 +670,14 @@ Lookup::bracket (Axis a, Interval iv, Real thick, Real protude, Real blot)
   b[a] = iv;
   b[other] = Interval (-1, 1) * thick * 0.5;
   
-  Stencil m =  round_filled_box (b, blot);
+  Stencil m = round_filled_box (b, blot);
 
   b[a] = Interval (iv[UP] - thick, iv[UP]);
-  Interval oi = Interval (-thick/2, thick/2 + fabs (protude)) ;
-  oi *=  sign (protude);
+  Interval oi = Interval (-thick/2, thick/2 + fabs (protude));
+  oi *= sign (protude);
   b[other] = oi;
   m.add_stencil (round_filled_box (b, blot));
-  b[a] = Interval (iv[DOWN], iv[DOWN]  +thick);
+  b[a] = Interval (iv[DOWN], iv[DOWN] + thick);
   m.add_stencil (round_filled_box (b,blot));
 
   return m;
@@ -694,14 +690,19 @@ Lookup::triangle (Interval iv, Real thick, Real protude)
   b[X_AXIS] = Interval (0, iv.length());
   b[Y_AXIS] = Interval (0 <? protude , 0 >? protude);
 
-  SCM s = scm_list_n (ly_symbol2scm ("symmetric-x-triangle"),
-		      scm_make_real (thick),
-		      scm_make_real (iv.length ()), 
-		      scm_make_real (protude), SCM_UNDEFINED);
 
-  Stencil stc (b, s);
-  stc.translate_axis (iv[LEFT], X_AXIS);
-  return stc;  
+  Offset z1(iv[LEFT], 0);
+  Offset z2(iv[RIGHT], 0);
+  Offset z3((z1 + z2)[X_AXIS]/2, protude);
+
+  /*
+    TODO: move Triangle to Line_interface ?
+   */
+  Stencil tri = Line_interface::make_line (thick, z1, z2);
+  tri.add_stencil (Line_interface::make_line (thick, z2, z3));
+  tri.add_stencil (Line_interface::make_line (thick, z3, z1));
+
+  return tri;
 }
 
 
